@@ -55,7 +55,8 @@ def train_batch(model, criterion, optimizer, vocab_size,
 def train_epoches(dataset, model, criterion, optimizer, 
                     vocab_size, teacher_forcing_ratio, 
                     config):
-    train_loader = DataLoader(dataset, config.batch_size)
+    # train_loader = DataLoader(dataset, config.batch_size)
+    train_loader = dataset
     model.train(True)
     prev_epoch_loss_list = [100] * config.num_of_exams
     for epoch in range(1, config.epochs + 1):
@@ -64,7 +65,7 @@ def train_epoches(dataset, model, criterion, optimizer,
         for batch_idx, (source, target, input_lengths) in enumerate(train_loader):
             input_variables = source
             target_variables = target
-            # train model
+            # train model              
             loss_list = train_batch(model, criterion, optimizer, vocab_size,
                                         input_variables, input_lengths.tolist(),
                                         target_variables, teacher_forcing_ratio,
